==> analitza_15.12.3.orig.tar.xz: analitza-15.12.3/analitzagui/tests/operatorsmodeltest.h <==
/*************************************************************************************
 *  Copyright (C) 2008 by Aleix Pol <aleixpol@kde.org>                               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#ifndef OPERATORSMODELTEST_H
#define OPERATORSMODELTEST_H

#include <QObject>
#include "../operatorsmodel.h"

/**
    @author Aleix Pol
*/

class OperatorsModelTest : public QObject
{
    Q_OBJECT
    public:
        OperatorsModelTest(QObject *parent = 0);
        ~OperatorsModelTest();
    
    private Q_SLOTS:
        void initTestCase();
        
        void testExamples_data();
        void testExamples();
        
        void cleanupTestCase();
        
    private:
        OperatorsModel m;
};

#endif

==> analitza-19.03.90.tar.xz: analitza-19.03.90/analitzagui/tests/operatorsmodeltest.h <==
/*************************************************************************************
 *  Copyright (C) 2008 by Aleix Pol <aleixpol@kde.org>                               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#ifndef OPERATORSMODELTEST_H
#define OPERATORSMODELTEST_H

#include <QObject>
#include "../operatorsmodel.h"

/**
    @author Aleix Pol
*/

class OperatorsModelTest : public QObject
{
    Q_OBJECT
    public:
        OperatorsModelTest(QObject *parent = nullptr);
        ~OperatorsModelTest();
    
    private Q_SLOTS:
        void initTestCase();
        
        void testExamples_data();
        void testExamples();
        
        void cleanupTestCase();
        
    private:
        OperatorsModel m;
};

#endif
